braindecode.datautil.filterbank
===============================

.. currentmodule:: braindecode.datautil

.. autofunction:: filterbank

.. include:: braindecode.datautil.filterbank.examples

.. raw:: html

    <div style='clear:both'></div>